@@ -114,7 +114,7 @@ DefaultPieceStorage::DefaultPieceStorage(
   }
 }
 
-DefaultPieceStorage::~DefaultPieceStorage() {}
+DefaultPieceStorage::~DefaultPieceStorage() = default;
 
 std::shared_ptr<Piece> DefaultPieceStorage::checkOutPiece(size_t index,
                                                           cuid_t cuid)
